@@ -13,9 +13,12 @@ from argparse import ArgumentParser, Namespace
 from typing import List, NewType, Optional, Tuple, Generator, Dict, Union, Any, AsyncGenerator, Awaitable, cast
 from typing_extensions import TypedDict, NotRequired, Protocol
 
+from scrapy.utils.misc import load_object
+from scrapy.statscollectors import StatsCollector
 from scrapinghub import ScrapinghubClient, DuplicateJobError
 from scrapinghub.client.jobs import Job, JobMeta
 from scrapinghub.client.projects import Project
+from shub_workflow.utils import get_project_settings
 
 from shub_workflow.utils import (
     resolve_project_id,
@@ -161,6 +164,7 @@ class BaseScript(ArgumentParserScript, BaseScriptProtocol):
         self.__flow_tags: List[str] = []
         super().__init__()
         self.set_flow_id_name(self.args)
+        self.project_settings = get_project_settings()
 
     def append_flow_tag(self, tag: str):
         """
@@ -287,6 +291,10 @@ class BaseScript(ArgumentParserScript, BaseScriptProtocol):
                 if metadata:
                     self._update_metadata(metadata, {"tags": job_tags})
 
+    async def async_add_job_tags(self, jobkey: Optional[JobKey] = None, tags: Optional[List[str]] = None):
+        loop = asyncio.get_event_loop()
+        return await loop.run_in_executor(None, partial(self.add_job_tags, jobkey, tags))
+
     def _get_flowid_name_from_tags(self, jobkey: Optional[JobKey] = None) -> Tuple[Optional[str], Optional[str]]:
         """If jobkey is None, get flowid from own tags"""
         tags = self.get_job_tags(jobkey)
@@ -420,6 +428,9 @@ class BaseScript(ArgumentParserScript, BaseScriptProtocol):
 
 
 class BaseLoopScriptProtocol(BaseScriptProtocol, Protocol):
+
+    stats: StatsCollector
+
     @abc.abstractmethod
     def workflow_loop(self) -> bool:
         """Implement here your loop code. Return True if want to continue looping,
@@ -432,6 +443,7 @@ class BaseLoopScriptProtocol(BaseScriptProtocol, Protocol):
     def _run_loops(self) -> Generator[bool, None, None]:
         ...
 
+    @abc.abstractmethod
     def base_loop_tasks(self):
         ...
 
@@ -448,6 +460,21 @@ class BaseLoopScript(BaseScript, BaseLoopScriptProtocol):
         super().__init__()
         self.__start_time = time.time()
 
+        class PseudoCrawler:
+            def __init__(self, script):
+                self.settings = script.project_settings
+
+        stats_collector_class = self.project_settings["STATS_CLASS"]
+        logger.debug(f"Stats collection class: {stats_collector_class}")
+        self.stats = load_object(stats_collector_class)(PseudoCrawler(self))
+        self.__close_reason = None
+
+    def set_close_reason(self, reason):
+        self.__close_reason = reason
+
+    def get_close_reason(self):
+        return self.__close_reason
+
     def add_argparser_options(self):
         super().add_argparser_options()
         self.argparser.add_argument(
@@ -475,9 +502,9 @@ class BaseLoopScript(BaseScript, BaseLoopScriptProtocol):
             if loop_result and self.args.loop_mode:
                 time.sleep(self.args.loop_mode)
             else:
-                self._close()
-                logger.info("No more tasks")
                 break
+        self._close()
+        logger.info("No more tasks")
 
     def base_loop_tasks(self):
         pass
@@ -502,12 +529,15 @@ class BaseLoopScript(BaseScript, BaseLoopScriptProtocol):
     def _on_start(self):
         self.on_start()
         self.workflow_loop_enabled = True
+        self.stats.open_spider(self)
 
     def on_close(self):
         pass
 
     def _close(self):
         self.on_close()
+        self.__close_reason = self.__close_reason or "finished"
+        self.stats.close_spider(self, self.__close_reason)
 
 
 class BaseLoopScriptAsyncMixin(BaseLoopScriptProtocol):
@@ -556,6 +586,6 @@ class BaseLoopScriptAsyncMixin(BaseLoopScriptProtocol):
             if loop_result and self.args.loop_mode:
                 await asyncio.sleep(self.args.loop_mode)
             else:
-                self._close()
-                logger.info("No more tasks")
                 break
+        self._close()
+        logger.info("No more tasks")
